@@ -7,7 +7,12 @@
 // Usage: anyExample_clt <object reference>
 //
 
-#include <iostream.h>
+#ifdef HAVE_STD
+#  include <iostream>
+   using namespace std;
+#else
+#  include <iostream.h>
+#endif
 #include <anyExample.hh>
 
 
@@ -69,22 +74,23 @@ static void hello(anyExample_ptr tobj)
 int main(int argc, char** argv)
 {
   try {
-    CORBA::ORB_var orb = CORBA::ORB_init(argc, argv, "omniORB3");
+    CORBA::ORB_var orb = CORBA::ORB_init(argc, argv);
 
     if( argc != 2 ) {
       cerr << "usage:  anyExample_clt <object reference>" << endl;
       return 1;
     }
 
-    CORBA::Object_var obj = orb->string_to_object(argv[1]);
-    anyExample_var ref = anyExample::_narrow(obj);
-    if( CORBA::is_nil(ref) ) {
-      cerr << "Can't narrow reference to type anyExample (or it was nil)."
-	   << endl;
-      return 1;
+    {
+      CORBA::Object_var obj = orb->string_to_object(argv[1]);
+      anyExample_var ref = anyExample::_narrow(obj);
+      if( CORBA::is_nil(ref) ) {
+	cerr << "Can't narrow reference to type anyExample (or it was nil)."
+	     << endl;
+	return 1;
+      }
+      hello(ref);
     }
-    hello(ref);
-
     orb->destroy();
   }
   catch(CORBA::COMM_FAILURE& ex) {
