@@ -1,27 +1,35 @@
-#include <iostream.h>
+#ifdef HAVE_STD
+#  include <iostream>
+   using namespace std;
+#else
+#  include <iostream.h>
+#endif
 #include <echo_callback.hh>
 
 
 int main(int argc, char** argv)
 {
   try {
-    CORBA::ORB_var orb = CORBA::ORB_init(argc, argv, "omniORB3");
+    CORBA::ORB_var orb = CORBA::ORB_init(argc, argv);
 
     if( argc != 2 ) {
       cerr << "usage:  cb_shutdown <server reference>" << endl;
       return 1;
     }
 
-    CORBA::Object_var obj = orb->string_to_object(argv[1]);
-    cb::Server_var server = cb::Server::_narrow(obj);
 
-    if( CORBA::is_nil(server) ) {
-      cerr << "cb_shutdown: The server reference is nil!" << endl;
-      return 1;
+    {
+      CORBA::Object_var obj = orb->string_to_object(argv[1]);
+      cb::Server_var server = cb::Server::_narrow(obj);
+
+      if( CORBA::is_nil(server) ) {
+	cerr << "cb_shutdown: The server reference is nil!" << endl;
+	return 1;
+      }
+
+      server->shutdown();
     }
 
-    server->shutdown();
-
     orb->destroy();
   }
   catch(CORBA::COMM_FAILURE& ex) {
