@@ -7,10 +7,14 @@
 // Usage: eg1
 //
 
-#include <iostream.h>
+#ifdef HAVE_STD
+#  include <iostream>
+   using namespace std;
+#else
+#  include <iostream.h>
+#endif
 #include <echo.hh>
 
-
 // This is the object implementation.
 
 class Echo_i : public POA_Echo,
@@ -56,24 +60,26 @@ static void hello(Echo_ptr e)
 
 int main(int argc, char** argv)
 {
+
+
   try {
     // Initialise the ORB.
-    CORBA::ORB_var orb = CORBA::ORB_init(argc, argv, "omniORB3");
+    CORBA::ORB_var orb = CORBA::ORB_init(argc, argv);
 
     // Obtain a reference to the root POA.
     CORBA::Object_var obj = orb->resolve_initial_references("RootPOA");
     PortableServer::POA_var poa = PortableServer::POA::_narrow(obj);
 
-    // We allocate the object on the heap.  Since this is a reference
-    // counted object, it will be deleted by the POA when it is no
-    // longer needed.
+      // We allocate the object on the heap.  Since this is a reference
+      // counted object, it will be deleted by the POA when it is no
+      // longer needed.
     Echo_i* myecho = new Echo_i();
 
     // Activate the object.  This tells the POA that this object is
     // ready to accept requests.
     PortableServer::ObjectId_var myechoid = poa->activate_object(myecho);
 
-    // Obtain a reference to the object.
+      // Obtain a reference to the object.
     Echo_var myechoref = myecho->_this();
 
     // Decrement the reference count of the object implementation, so
